@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -12,20 +12,17 @@ knitr::opts_chunk$set(
   warning = FALSE
 )
 
-# CRAN OMP THREAD LIMIT
-Sys.setenv("OMP_THREAD_LIMIT" = 1)
-
-## ---- echo=F,  out.width="100%", fig.align='center'---------------------------
+## ----echo=F,  out.width="100%", fig.align='center'----------------------------
 knitr::include_graphics("forecast_plot.jpg")
 
-## ---- echo=F,  out.width="100%", fig.align='center', fig.cap="The Modeltime Workflow"----
+## ----echo=F,  out.width="100%", fig.align='center', fig.cap="The Modeltime Workflow"----
 knitr::include_graphics("modeltime_workflow.jpg")
 
-## -----------------------------------------------------------------------------
+## ----include=FALSE------------------------------------------------------------
 library(xgboost)
 library(tidymodels)
 library(modeltime)
-library(tidyverse)
+library(dplyr)
 library(lubridate)
 library(timetk)
 
@@ -44,13 +41,13 @@ m750 %>%
 # Split Data 80/20
 splits <- initial_time_split(m750, prop = 0.9)
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 1: auto_arima ----
 model_fit_arima_no_boost <- arima_reg() %>%
     set_engine(engine = "auto_arima") %>%
     fit(value ~ date, data = training(splits))
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 2: arima_boost ----
 model_fit_arima_boosted <- arima_boost(
     min_n = 2,
@@ -60,27 +57,28 @@ model_fit_arima_boosted <- arima_boost(
     fit(value ~ date + as.numeric(date) + factor(month(date, label = TRUE), ordered = F),
         data = training(splits))
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 3: ets ----
 model_fit_ets <- exp_smoothing() %>%
     set_engine(engine = "ets") %>%
     fit(value ~ date, data = training(splits))
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 4: prophet ----
 model_fit_prophet <- prophet_reg() %>%
     set_engine(engine = "prophet") %>%
     fit(value ~ date, data = training(splits))
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 5: lm ----
 model_fit_lm <- linear_reg() %>%
     set_engine("lm") %>%
     fit(value ~ as.numeric(date) + factor(month(date, label = TRUE), ordered = FALSE),
         data = training(splits))
 
-## ---- message=TRUE------------------------------------------------------------
+## ----message=TRUE-------------------------------------------------------------
 # Model 6: earth ----
+
 model_spec_mars <- mars(mode = "regression") %>%
     set_engine("earth") 
 
@@ -95,7 +93,7 @@ wflw_fit_mars <- workflow() %>%
     add_model(model_spec_mars) %>%
     fit(training(splits))
 
-## ---- paged.print = FALSE-----------------------------------------------------
+## ----paged.print = FALSE------------------------------------------------------
 models_tbl <- modeltime_table(
     model_fit_arima_no_boost,
     model_fit_arima_boosted,
@@ -107,7 +105,7 @@ models_tbl <- modeltime_table(
 
 models_tbl
 
-## ---- paged.print = FALSE-----------------------------------------------------
+## ----paged.print = FALSE------------------------------------------------------
 calibration_tbl <- models_tbl %>%
     modeltime_calibrate(new_data = testing(splits))
 
@@ -131,7 +129,7 @@ calibration_tbl %>%
         .interactive = interactive
     )
 
-## ---- paged.print = F, message=F----------------------------------------------
+## ----paged.print = F, message=F-----------------------------------------------
 refit_tbl <- calibration_tbl %>%
     modeltime_refit(data = m750)
 
