@@ -2,8 +2,6 @@ library(testthat)
 
 library(xgboost)
 library(randomForest)
-library(kernlab)
-library(earth)
 library(thief)
 library(smooth)
 library(greybox)
@@ -17,15 +15,10 @@ library(rsample)
 library(recipes)
 library(tune)
 library(dials)
-library(TSrepr)
 library(yardstick)
 library(slider)
 
 library(timetk)
 library(modeltime)
 
-library(tidyverse)
-library(lubridate)
-
-
 test_check("modeltime")
