@@ -9,23 +9,23 @@ test_that("Test Modeltime Residuals Tests", {
     skip_on_cran()
 
     # Data
-    m750   <- m4_monthly %>% filter(id == "M750")
-    splits <- initial_time_split(m750, prop = 0.8)
+    m750   <- timetk::m4_monthly %>% dplyr::filter(id == "M750")
+    splits <- rsample::initial_time_split(m750, prop = 0.8)
 
     # Model Spec
     model_fit_arima <- arima_reg() %>%
-        set_engine("auto_arima") %>%
-        fit(value ~ date, training(splits))
+        parsnip::set_engine("auto_arima") %>%
+        fit(value ~ date, rsample::training(splits))
 
     model_fit_prophet <- prophet_reg() %>%
-        set_engine("prophet") %>%
-        fit(value ~ date, training(splits))
+        parsnip::set_engine("prophet") %>%
+        fit(value ~ date, rsample::training(splits))
 
     model_fit_lm <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ splines::ns(date, df = 5)
-            + month(date, label = TRUE),
-            training(splits))
+            + lubridate::month(date, label = TRUE),
+            rsample::training(splits))
 
     # Model Table
     model_tbl <- modeltime_table(
@@ -35,26 +35,26 @@ test_that("Test Modeltime Residuals Tests", {
     )
 
     residuals_tbl <- model_tbl %>%
-        modeltime_calibrate(testing(splits)) %>%
+        modeltime_calibrate(rsample::testing(splits)) %>%
         modeltime_residuals()
 
     res_tbl_1 <- residuals_tbl %>% modeltime_residuals_test()
 
-    res_tbl_2 <- model_tbl %>% modeltime_residuals_test(training(splits))
+    res_tbl_2 <- model_tbl %>% modeltime_residuals_test(rsample::training(splits))
 
-    res_tbl_3 <- model_tbl %>% modeltime_residuals_test(testing(splits))
+    res_tbl_3 <- model_tbl %>% modeltime_residuals_test(rsample::testing(splits))
 
     res_tbl_4 <- model_fit_arima %>%
-                 modeltime_calibrate(new_data = training(splits)) %>%
-                 modeltime_residuals_test(new_data = training(splits))
+                 modeltime_calibrate(new_data = rsample::training(splits)) %>%
+                 modeltime_residuals_test(new_data = rsample::training(splits))
 
     res_tbl_5 <- model_fit_arima %>%
-                 modeltime_calibrate(new_data = testing(splits)) %>%
-                 modeltime_residuals_test(new_data = testing(splits))
+                 modeltime_calibrate(new_data = rsample::testing(splits)) %>%
+                 modeltime_residuals_test(new_data = rsample::testing(splits))
 
-    res_tbl_6 <- residuals_tbl %>% modeltime_residuals_test(training(splits))
+    res_tbl_6 <- residuals_tbl %>% modeltime_residuals_test(rsample::training(splits))
 
-    res_tbl_7 <- residuals_tbl %>% modeltime_residuals_test(testing(splits))
+    res_tbl_7 <- residuals_tbl %>% modeltime_residuals_test(rsample::testing(splits))
 
     # Structure
     nms_expected <- c(".model_id", ".model_desc", "shapiro_wilk", "box_pierce", "ljung_box", "durbin_watson")
@@ -88,7 +88,7 @@ test_that("Test Modeltime Residuals Tests", {
 
     expect_error({
         # Missing new_data or calibration data
-        model_fit_arima %>% modeltime_residuals_test(new_data = training(splits))
+        model_fit_arima %>% modeltime_residuals_test(new_data = rsample::training(splits))
     })
 
     expect_error({
